============================
Tempest Integration of Kuryr
============================

Overview
========

This project defines a tempest plugin containing tests used to verify the
functionality of a kuryr installation. The plugin will automatically load
these tests into tempest.
